#!/usr/bin/python
# -*- coding: UTF-8 -*-

# --- [ analog_input.py ] --------------------------------------------------------
#
# ---   08.07.2014

import tkinter as tk
import bargraph as bg
import net_io_tools as ni

class ADC(tk.Frame):
    """ In einem Frame als unsichtbaren Container werden 2 Labels
        als Bezeichnungs- und Statusfeld beinhaltet eingebaut.

        set_Value(value) aktualisiert das Statusfeld mit dem Wert,
        get_Value() liefert den aktuelle Wert des Statusfeldes """

    def __init__(self, master,
                  zeile = 0,
                  text = "",
                  font = ("Courier", 10, "bold") ):

        tk.Frame.__init__(self, master)

        tk.Label(self, text = text, width = 10 , font = font, anchor = "e").grid(
                column = 0, row = zeile, padx = 5, pady = 3, sticky = "nse")

        self._var = tk.IntVar()
        tk.Label(self, width = 5, relief = "groove", font = font,
                textvariable = self._var).grid(
                column = 1, row = 0, padx = 5, pady = 3)


    def set_Value(self, value):
        self._var.set(value)


    def get_Value(self):
        return self._var.get()


class Inputs(tk.LabelFrame):
    def __init__(self, master, column = 0, row = 0):
        tk.LabelFrame.__init__(self, text = "ADC-Inputs")
        self.grid(column = column, columnspan = 2, row = row,
                                padx = 5, pady = 5, sticky = "nsew")
        # Bezeichner, Row, Bargraph(Faktor, Bezeichner, Einheit)
        items = (("Analog 1:", 0, (5, "Va", "mV")),
                 ("Analog 2:", 1, (5, "Vb", "mV")),
                 ("Analog 3:", 2, (5, "Vc", "mV")),
                 ("Analog 4:", 3, (5, "Vd", "mV")),)
        self.adcs = []
        self.bgs = []
        for i in range(len(items)):
            self.adcs.append(ADC(self, text = items[i][0] ))
            self.adcs[i].grid(column = column, row = items[i][1],
                                padx = 5, pady = 5, sticky = "nsew")

            self.bgs.append(bg.BarGraph(self, width = 256, end_value = 1023,
                                label = items[i][2]))
            self.bgs[i].grid(column = 1, row = items[i][1],
                                padx = 5, pady = 5, sticky = "nsew")


    def show_Adcs(self, file = None):
        """ Die Werte der ADC's einzeln auslesen und anzeigen """
        val = []
        for i in range(len(self.adcs)):
            j = ni.Get_Adc(i + 1)
            val.append(j)
            self.adcs[i].set_Value(j)
            self.bgs[i].set_Value(j)

        if file is not None:
            file.write(str(val))


    def get_Adcs(self):
        """ Die Werte der ADC's einzeln auslesen, anzeigen und zurückgeben """
        m = []
        for i in range(len(self.adcs)):
            j = ni.Get_Adc(i + 1)
            m.append(j)
            self.adcs[i].set_Value(j)
            self.bgs[i].set_Value(j)
        return m


if __name__ == "__main__":
    class App(tk.Tk):
        def __init__(self):
            tk.Tk.__init__(self)
            self.title("Test Analog Input")

            self.adc = Inputs(self)

            print(ni.Start_Telnet())
            self.after(1000, self.animate)
            self.mainloop()


        def animate(self):
            ni.Open_Telnet()

            self.adc.show_Adcs()
            ni.Close_Telnet()

            self.after(1000, self.animate)

    App()


# --- [ eof ] ------------------------------------------------------------------
