#!/usr/bin/python
# -*- coding: UTF-8 -*-

# --- [ digi_input.py ] --------------------------------------------------------
#
# ---   08.07.2014

import tkinter as tk
import net_io_tools as ni


class Input_pin(tk.Frame):
    """ In einen Frame als unsichtbaren Container werden 2 Labels
        als Bezeichnungs- und Statusfeld beinhaltet eingebaut.

        set_Button(value) aktualisiert das Statusfeld mit dem Wert,
        get_Button() liefert den aktuelle Wert des Statusfeldes """

    def __init__(self, master,
                zeile = 0,
                text = "",
                font = ("Courier", 10, "bold")):

        tk.Frame.__init__(self, master)

        self._lbl1 = tk.Label(self, text = text, width = 10 , font = font, anchor = "e")
        self._lbl1.grid(column = 0, row = zeile, padx = 5, pady = 2, sticky = "nse")

        self._lbl2 = tk.Label(self, width = 5)
        self._lbl2.grid(column = 1, row = 0, padx = 5, pady = 2)
        self._var = tk.StringVar()
        self._var.set(0)
        self._lbl2.config(textvariable = self._var)


    def set_Button(self, value):
        """ Ändert die Darstellung des Widgets entsprechend des Pinstatus """
        if value == 0:
            self._var.set("low")
            self._lbl2.configure(relief = "raised")

        else:
            self._var.set("high")
            self._lbl2.configure(relief = "sunken")


    def get_Button(self):
        return self._var.get()


class Inputs(tk.LabelFrame):
    def __init__(self, master, column = 0, row = 0):
        tk.LabelFrame.__init__(self, master, text = "Digital Inputs")
        self.grid(column = column, row = row, padx = 5, pady = 5, sticky = "nsew")

        items = (("Input 1:", 0),
                 ("Input 2:", 1),
                 ("Input 3:", 2),
                 ("Input 4:", 3),)

        self.inputs = []
        for i in range(len(items)):
            self.inputs.append(Input_pin(self, text = items[i][0]) )
            self.inputs[i].grid(column = 0, row = items[i][1],
                                    padx = 5, pady = 5, sticky = "nsew")

    def get_Inputs(self):
        """ Die Eingänge des NetIO auslesen und anzeigen und zurückgeben """
        pinstate = ni.Get_Pin_State()
        for i in range(len(pinstate)):
            self.inputs[i].set_Button(pinstate[i])
        return pinstate

    def show_Inputs(self, file = None):
        """ Die Eingänge des NetIO auslesen und anzeigen """
        pinstate = ni.Get_Pin_State()
        for i in range(len(pinstate)):
            self.inputs[i].set_Button(pinstate[i])

        if file is not None:
            file.write( str(pinstate))


if __name__ == "__main__":

    import net_io_tools as ni

    class App(tk.Tk):
        def __init__(self):
            tk.Tk.__init__(self)
            self.title("Test DigiInput")

            self.inputs = Inputs(self)

            print(ni.Start_Telnet())
            self.after(2000, self.animate)
            self.mainloop()


        def animate(self):
            """ zum Testen der Anzeige """
            ni.Open_Telnet()
            self.inputs.show_Inputs()
            ni.Close_Telnet()
            self.after(1000, self.animate)

    App()


# --- [ eof ] ------------------------------------------------------------------
