#!/usr/bin/python
# -*- coding: UTF-8 -*-

# --- [ digi_output.py ] --------------------------------------------------------
#
# ---   08.07.2014

import tkinter as tk
import net_io_tools as ni

class Output_pin(tk.Checkbutton):
    """ Ein Checkbutton mit einem Label ermöglicht, den Status eines Pins zu ändern.
        Beim Anklicken wird der neue Status gesendet.
        set_Button() übergibt den aktuellen Pinstatus
    """
    def __init__(self, master,
                  portpin = 0,              # Der jeweilige Portpin, der geschaltet werden soll
                  label_text = "",
                  font = ("Courier", 10, "bold")):

        tk.Checkbutton.__init__(self, master, text = label_text,
                             width = 12,
                             font = font,
                             command = self._set_Pinstate,
                             anchor = "w" )

        self._portpin = portpin                 # der zu schaltende PortPin am Netio
        self._chkvar = tk.IntVar()
        self._chkvar.set(0)
        self.config(variable = self._chkvar)


    def set_Button(self, value):
        """ wenn der Status des Netio ausgelesen wird, dann werden
            der aktuelle Pinstatus ins Widget geschrieben
        """
        if value:
            self.configure(relief = "sunken")
        else:
            self.configure(relief = "raised")
        self._chkvar.set(value)


    def _set_Pinstate(self):
        """ Wird ausgeführt, wenn ein Button geändert wird.
            Liest den aktuelle Button-Status aus,
            ändert die Darstellung des Widgets und
            versendet den Wert mit dem PinStatus des zugehörigen Output-Pins
            an das Netio.
        """
        self.set_Button(self._chkvar.get())
        try:
            ni.Open_Telnet()
            ni.Set_Port_State(self._portpin, self._chkvar.get())
            ni.Close_Telnet()

        except: # (BaseException) as e:
            #print(e)
            print("Telnet-Error")


class Outputs(tk.LabelFrame):
    """ Hier wird ein Labelframe mit 8 Schaltern für die 8 Outputpins erstellt.
    """
    def __init__(self, master, column = 0, row = 0):
        tk.LabelFrame.__init__(self, master, text = "Digital Outputs")
        self.grid(column = column, row = row, padx = 5, pady = 5, sticky = "nsew")

        # Bezeichner, Column, Row
        items = (("Schalter 1", 0, 0),
                 ("Schalter 2", 0, 1),
                 ("Schalter 3", 0, 2),
                 ("Schalter 4", 0, 3),
                 ("Schalter 5", 1, 0),
                 ("Schalter 6", 1, 1),
                 ("Schalter 7", 1, 2),
                 ("Schalter 8", 1, 3),)

        self._btns = []
        for i in range(len(items)):
            self._btns.append(Output_pin(self, label_text = items[i][0],
                                        portpin = i + 1))
            self._btns[i].grid(column = items[i][1], row = items[i][2],
                                        padx = 5, pady = 5, sticky = "nsew")


    def show_Outputs(self, file = None):
        """ Holt den Status der Pins vom Netio ab und
            aktualisiert die Anzeige.
        """
        p = ni.Get_Port_State()

        for i in range(len(self._btns)):
            self._btns[i].set_Button(p[i])

        if file is not None:
            file.write(str(p))

    def get_Outputs(self):
        """ Holt den Status der Pins vom Netio ab,
            aktualisiert die Anzeige und gibt die Werte zurück.
        """
        t = ni.Get_Port_State()
        for i in range(len(self._btns)):
            self._btns[i].set_Button(t[i])
        return t


if __name__ == "__main__":

    class App(tk.Tk):
        def __init__(self):
            tk.Tk.__init__(self)
            self.title("Test Digital Outputs")

            self.output = Outputs(self)

            print(ni.Start_Telnet())

            self.after(1000, self.animate)
            self.mainloop()


        def animate(self):
            """ zum Testen der Anzeige """
            ni.Open_Telnet()
            self.output.show_Outputs()
            ni.Close_Telnet()

            self.after(2000, self.animate)

    App()
# --- [ eof ] ------------------------------------------------------------------
