#!/usr/bin/python
# -*- coding: UTF-8 -*-
#
# --- 08.07.2014
#
# --- [ lcd_outputs.py ] --------------------------------------------------------

import tkinter as tk
import net_io_tools as ni
import time

class Lcd_output(tk.Frame):
    """ In einen Frame als unsichtbaren Container werden 1 Label, 1 Entry-Feld
        und zwei Buttons eingebaut.

        deactivate() deaktiviert die Eingabefelder (wenn kein LCD vorhanden ist) """

    lcd_found = True

    def __init__(self, master,
                 font = ("Courier", 10, "bold"),
                 lcd_row = 1 ):

        tk.Frame.__init__(self, master)

        self._lbl = tk.Label(self, text = "LCD Zeile {}:".format(lcd_row), width = 13, anchor = "e" ,font = font )
        self._lbl.grid(column = 0, row = 0, padx = 5, pady = 2, sticky = "e")

        self._var = tk.StringVar()
        self._entry = tk.Entry(self, width = 16 , font = font, textvariable = self._var)
        self._entry.grid(column = 1, row = 0, padx = 5, pady = 2, sticky = "nse")

        self._check = self._entry.register(self.isOK)
        self._entry.configure(validate = 'key',
                               validatecommand = (self._check, '%P'))

        self._btn = tk.Button(self, width = 18, text = "Zeile löschen", font = font, command = self._clr_row)
        self._btn.grid(column = 3, row = 0, padx = 5, pady = 2, sticky = "nse")

        self._lcd_row = lcd_row


    def isOK(self, new_value):
        """ hier wird jede Eingabe geprüft -
            es wird immer der aktuelle Eintrag ans LCD geschickt
            und ein True zurückzugegeben,
        """
        t = new_value

        if len(t) > 16:
            self.bell()
            return False

        try:
            ni.Open_Telnet()
            ni.Write_LCD(self._lcd_row, t)
            ni.Close_Telnet()

        except:
            print("Telnet-error")
            return False

        return True


    def _clr_row(self):
        """ Button Zeile Löschen betätigt """
        if Lcd_output.lcd_found is True:
            self._var.set("")
            try:
                ni.Open_Telnet()
                ni.Clear_LCD(self._lcd_row)
                ni.Close_Telnet()
            except:
                print("Telnet_error")
        else:
            #print("bell")
            self.bell()

    def disable(self):
        # diese Zeile verzögert den Programmstart um 10 Sekunden
        #self._var.set("  no lcd found")
        self._entry.configure(state  = "disabled")
        self._btn.configure(text = "disabled")


class Outputs(tk.LabelFrame):
    def __init__(self, master, column = 0, row = 0):
        tk.LabelFrame.__init__(self, master, text = "LCD-Ausgabe")
        self.grid(column = column, columnspan = 2, row = row,
                                        padx = 5, pady = 5, sticky = "nsew")

        self.lcd1 = Lcd_output(self, lcd_row = 1)
        self.lcd1.grid(column = 0, row = 0, padx = 5, pady = 5, sticky = "nsew")

        self.lcd2 = Lcd_output(self, lcd_row = 2)
        self.lcd2.grid(column = 0, row = 1, padx = 5, pady = 5, sticky = "nsew")


    def check(self):
        """ Prüfen, ob das LCD gefunden wird,
            wenn nicht, dann die Eingabezeile deaktivieren """

        ni.Open_Telnet()

        if ni.Init_LCD():
            Lcd_output.lcd_found = True

        else:
            Lcd_output.lcd_found = False
            self.lcd1.disable()
            self.lcd2.disable()

        ni.Close_Telnet()


    def disable(self):
        Lcd_output.lcd_found = False
        self.lcd1.disable()
        self.lcd2.disable()


if __name__ == "__main__":

    class App(tk.Tk):
        def __init__(self):
            tk.Tk.__init__(self)
            self.title("LCD-Test")

            self.lcd = Outputs(self)

            print(ni.Start_Telnet())

            ni.Open_Telnet()
            if not ni.Init_LCD():
                print("kein LCD gefunden")
                exit()

            ni.Close_Telnet()
            self.after(3000, self.animate)

            self.mainloop()

        def animate(self):
            #self.lcd.deactivate()
            pass

    App()


# --- [ eof ] ------------------------------------------------------------------
