#!/usr/bin/python
# -*- coding: UTF-8 -*-
#
# --- [ netio_main.py ] -------------------------------------------------------
#
# ---   08.07.2014

import tkinter as tk
from tkinter import messagebox
from tkinter import filedialog
import time

import net_io_tools  as ni
import digi_inputs   as di
import analog_inputs as ai
import digi_outputs  as do
import lcd_outputs   as lcd
import config as cfg


class App(tk.Tk):
    def __init__(self):
        tk.Tk.__init__(self)
        self.title("Netio")
        self.bind_class('Tk', '<Destroy>', self.__xquit)

        self.readintervall = 10
        self.intervall_counter = 1
        self.read_activ = tk.IntVar()
        self.read_activ.set(1)
        self.file = None
        self.log_activ = tk.IntVar()        # default = 0

        self.add_Menus()
        self.add_Widgets()
        self.add_Connections()

        self.netio_init()
        self.__messung()                      # die erste Messung ausführen
        self.after(1000, self.timer)

        self.mainloop()


    def add_Menus(self):
        """ Hier werden die Items der Menüleiste eingefügt """
        self.menuleiste = tk.Menu(self)
        self.configure(menu = self.menuleiste)
#        self['menu'] = self.menuleiste

        self.dateimenue = tk.Menu(master = self.menuleiste)
        self.dateimenue.add_checkbutton(label = "Aktualisierung automatisch",
                                variable = self.read_activ, onvalue = 1,
                                offvalue = 0, command = self.__stop_messung)

        self.dateimenue.add_checkbutton(label = "Daten in Datei loggen",
                                variable = self.log_activ, onvalue = 1,
                                offvalue = 0, command = self.__file_save)
        self.dateimenue.add_separator()

        self.dateimenue.add_command(label = "NET-IO-Version", command = self.__info)

        self.dateimenue.add_separator()

        self.dateimenue.add_command(label = "Beenden", command = self.__quit)
        self.menuleiste.add_cascade(label = "Datei", menu = self.dateimenue)


    def add_Widgets(self):
        """ Hier wird die Oberfläche aufgebaut """
        self.dig_i = di.Inputs(self, column = 0, row = 0)
        self.dig_o = do.Outputs(self, column = 1, row = 0)
        self.ana_i = ai.Inputs(self, column = 0, row = 1)
        self.lcd_o = lcd.Outputs(self, column = 0, row = 2)
        self.cfg   = cfg.Readintervall(self, column =0, row = 3)


    def add_Connections(self):
        """ Hier werden die Verbindungen der Teile untereinander definiert """

        # wenn im Objekt cfg
        # - der Spinbutton mit dem Aktualisierungsintervall geändert wird,
        #   dann wird __intervall_cfg() aufgeführt
        # - der Button "Aktualisieren" gedrückt wird,
        #   dann wird __messung() aufgegeführt
        self.cfg.set_callback(self.__intervall_cfg, self.__messung)


    def netio_init(self):
        # schauen, ob die Verbindung zum Server steht
        self.netio_message = ni.Start_Telnet()

        if self.netio_message[2] is False:
            self.telnet_error = True
            self.__info()       # eine Fehlermeldung ausgeben
        else:
            self.telnet_error = False

        # die Verbindungsdaten in Fenstertitel aufnehmen
        self.title("AVR-NET-IO - " + self.netio_message[0])

        # prüfen ob ein LCD erkannt wird
        # wenn nicht, dann wird dabei die LCD-Zeile deaktiviert
        if not self.telnet_error:
             self.lcd_o.check()

        # bei einem Netzwerkfehler die LCD-Eingabezeile disablen
        else:
            self.lcd_o.disable()


    def timer(self):
        """ Wird jede Sekunde aufgerufen, zeigt die Zeit bis zur nächsten Messung
            an und führt eine Messung aus, wenn der Zähler 'intervall_counter'
            abgelaufen ist.
        """
        self.intervall_counter -= 1
        if self.intervall_counter <= 0:
            self.intervall_counter = self.readintervall
            self.__messung()
        else:
            self.cfg.update(self.intervall_counter)

        # neue Messung nur dann, wenn der Checkbutton aktiviert ist
        if self.read_activ.get():
            if not self.telnet_error:
                self.after(1000, self.timer)
                self.cfg.update(self.intervall_counter)
            else:
                self.cfg.update(-1)
        else:
             self.cfg.update(-1)


    def __messung(self):
        """ Hier werden die Messungen ausgeführt """
        if not self.telnet_error:
            try:
                if self.file is not None:
                    self.file.write(time.strftime("%H:%M:%S"))

                ni.Open_Telnet()

                self.ana_i.show_Adcs(self.file)
                self.dig_i.show_Inputs(self.file)
                self.dig_o.show_Outputs(self.file)

                if self.file is not None:
                    self.file.write("\r")

                ni.Close_Telnet()

            except:
                messagebox.showerror("Net-IO", "Netzwerk- oder IO-Fehler")
                self.telnet_error = True
            # den Counter für das Leseintervall neu setzen
            self.intervall_counter = self.readintervall


    def __intervall_cfg(self, i):
        if i > 0:
            self.readintervall = i
            if self.intervall_counter > i:
                self.intervall_counter = i


    def __stop_messung(self):
        """ Die Messungen wieder starten, wenn sie deaktiviert waren,
            wird ausgeführt, wenn der Checkbutton im Menü geändert wird """
        if self.read_activ.get():
            self.intervall_counter = self.readintervall
            self.cfg.update(self.intervall_counter)
            self.after(1000, self.timer)


    def __file_save(self):
        """ Die Daten in eine Datei ausgeben """
        if self.log_activ.get():
            filename = filedialog.asksaveasfilename(defaultextension = '.txt',\
                                    title = "Daten speichern",\
                                    initialfile = "data",\
                                    filetypes =[("LOG", "*.log")] )
            if filename is not None:
                try:
                    self.file = open(filename, "w")

                except:
                    pass
        else:
            self.file.close()
            self.file = None
            messagebox.showinfo("Net-IO", "Logdatei geschlossen")

    def __info(self):
        """ Gibt Versionshinweise zum Netio aus"""
        messagebox.showinfo("AVR-NET-IO Info", self.netio_message[1])


    def __quit(self):
        """ wird aus dem Menü heraus aufgerufen und ruft dann seinerseits
            xquit() auf. """
        self.destroy()


    def __xquit(self, e = None):
        """ hierüber läuft das Programmende, gleichgültig ob über das Menü
            oder das 'X' beendet wurde.
            Hier können offene Dateien geschlossen werden.
        """
        if self.file is not None:
            self.file.close()
            self.file = None
            print("File closed")


if __name__ == '__main__':
    App()
